==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDSCREENFIELDVALUEPAIR.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENFIELDNAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENFIELDVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userdefinedscreenfieldname",
    "userdefinedscreenfieldvalue"
})
@XmlRootElement(name = "USERDEFINEDSCREENFIELDVALUEPAIR")
public class USERDEFINEDSCREENFIELDVALUEPAIR {

    @XmlElement(name = "USERDEFINEDSCREENFIELDNAME")
    protected String userdefinedscreenfieldname;
    @XmlElement(name = "USERDEFINEDSCREENFIELDVALUE")
    protected USERDEFINEDSCREENFIELDDATA_Type userdefinedscreenfieldvalue;

    /**
     * Obtient la valeur de la propriété userdefinedscreenfieldname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERDEFINEDSCREENFIELDNAME() {
        return userdefinedscreenfieldname;
    }

    /**
     * Définit la valeur de la propriété userdefinedscreenfieldname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERDEFINEDSCREENFIELDNAME(String value) {
        this.userdefinedscreenfieldname = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedscreenfieldvalue.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDSCREENFIELDDATA_Type }
     *     
     */
    public USERDEFINEDSCREENFIELDDATA_Type getUSERDEFINEDSCREENFIELDVALUE() {
        return userdefinedscreenfieldvalue;
    }

    /**
     * Définit la valeur de la propriété userdefinedscreenfieldvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDSCREENFIELDDATA_Type }
     *     
     */
    public void setUSERDEFINEDSCREENFIELDVALUE(USERDEFINEDSCREENFIELDDATA_Type value) {
        this.userdefinedscreenfieldvalue = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDSCREENFIELDVALUEPAIR.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENFIELDNAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENFIELDVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userdefinedscreenfieldname",
    "userdefinedscreenfieldvalue"
})
@XmlRootElement(name = "USERDEFINEDSCREENFIELDVALUEPAIR")
public class USERDEFINEDSCREENFIELDVALUEPAIR {

    @XmlElement(name = "USERDEFINEDSCREENFIELDNAME")
    protected String userdefinedscreenfieldname;
    @XmlElement(name = "USERDEFINEDSCREENFIELDVALUE")
    protected USERDEFINEDSCREENFIELDDATA_Type userdefinedscreenfieldvalue;

    /**
     * Gets the value of the userdefinedscreenfieldname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERDEFINEDSCREENFIELDNAME() {
        return userdefinedscreenfieldname;
    }

    /**
     * Sets the value of the userdefinedscreenfieldname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERDEFINEDSCREENFIELDNAME(String value) {
        this.userdefinedscreenfieldname = value;
    }

    /**
     * Gets the value of the userdefinedscreenfieldvalue property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDSCREENFIELDDATA_Type }
     *     
     */
    public USERDEFINEDSCREENFIELDDATA_Type getUSERDEFINEDSCREENFIELDVALUE() {
        return userdefinedscreenfieldvalue;
    }

    /**
     * Sets the value of the userdefinedscreenfieldvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDSCREENFIELDDATA_Type }
     *     
     */
    public void setUSERDEFINEDSCREENFIELDVALUE(USERDEFINEDSCREENFIELDDATA_Type value) {
        this.userdefinedscreenfieldvalue = value;
    }

}
